netapp_ontap.resources.top_metrics_user API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.top_metrics_user`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

You can use this API to retrieve a list of users with the most I/O activity for a specified volume, within the past several seconds. Use the `top_metric` parameter to specify which type of I/O activity to filter for. This API is used to provide insight into I/O activity and supports ordering by I/O activity types, namely `iops` or `throughput` metrics. This API also supports only returning one I/O activity type per request.

## Approximate accounting and error bars

When too many users have recent activity, some users might be dropped from the list. In this situation, the spread of values in the `error` field increases, indicating that there are larger error bars on the value for `iops` or `throughput`. As the list becomes increasingly more approximate due to dropped entries, some of the users that would have otherwise been included might not be present in the final list returned by the API.

## Failure to return list of users with most I/O activity

The API can sometimes fail to return the list of users with the most I/O activity, due to the following reasons:

- The volume does not have the activity tracking feature enabled.
- The volume has not had any recent NFS/CIFS client traffic.
- The NFS/CIFS client operations are being served by the client-side filesystem cache.
- The NFS/CIFS client operations are being buffered by the client operating system.
- On rare occasions, the incoming traffic pattern is not suitable to obtain the list of users with the most I/O activity.
- NFSv4 client read operations using Multi-Processor I/O (MPIO) are not tracked.

## Failure to return the usernames

The API can sometimes fail to obtain the usernames for the list of userid entries, due to internal transient errors. In such cases, instead of the username, the API will return "{}" for the user entry.

## Retrieve a list of the users with the most I/O activity

For a report on the users with the most I/O activity returned in descending order, specify the I/O activity type you want to filter for by passing the `iops` or `throughput` property into the top_metric parameter. If the I/O activity type is not specified, by default the API returns a list of the users with the greatest number of the average read operations per second. The current maximum number of users returned by the API for an I/O activity type is 25.

- GET /api/storage/volumes/{volume.uuid}/top-metrics/users

## Examples

### Retrieving a list of the users with the greatest average number of read bytes received per second:

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import TopMetricsUser

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(
            list(
                TopMetricsUser.get_collection("{volume.uuid}", top_metric="throughput.read")
            )
        )

Try it out

    [
        TopMetricsUser(
            {
                "user_id": "S-1-5-21-256008430-3394229847-3930036330-1001",
                "svm": {
                    "name": "vs1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/572361f3-e769-439d-9c04-2ba48a08ff43"
                        }
                    },
                    "uuid": "572361f3-e769-439d-9c04-2ba48a08ff43",
                },
                "volume": {"name": "vol1"},
                "throughput": {
                    "error": {"lower_bound": 1495, "upper_bound": 1502},
                    "read": 1495,
                },
                "user_name": "John",
            }
        ),
        TopMetricsUser(
            {
                "user_id": "1988",
                "svm": {
                    "name": "vs1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/572361f3-e769-439d-9c04-2ba48a08ff43"
                        }
                    },
                    "uuid": "572361f3-e769-439d-9c04-2ba48a08ff43",
                },
                "volume": {"name": "vol1"},
                "throughput": {
                    "error": {"lower_bound": 1022, "upper_bound": 1025},
                    "read": 1022,
                },
                "user_name": "Ryan",
            }
        ),
        TopMetricsUser(
            {
                "user_id": "S-1-5-21-256008430-3394229847-3930036330-1003",
                "svm": {
                    "name": "vs1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/572361f3-e769-439d-9c04-2ba48a08ff43"
                        }
                    },
                    "uuid": "572361f3-e769-439d-9c04-2ba48a08ff43",
                },
                "volume": {"name": "vol1"},
                "throughput": {
                    "error": {"lower_bound": 345, "upper_bound": 348},
                    "read": 345,
                },
                "user_name": "Julie",
            }
        ),
    ]

## Example showing the behavior of the API when there is no read/write traffic:

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import TopMetricsUser

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(
            list(
                TopMetricsUser.get_collection(
                    "{volume.uuid}", top_metric="throughput.write"
                )
            )
        )

Try it out

    []

## Classes

`class TopMetricsUser (*args, **kwargs)`

  Information about a user's IO activity.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection (*args, connection: HostConnection = None, **kwargs) -> int`

    Returns a count of all TopMetricsUser resources that match the provided query

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def fast_get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[RawResource]`

    Returns a list of RawResources that represent TopMetricsUser resources that match the provided query

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def find (*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves a list of users with the most I/O activity.

    ### Learn more

    - `DOC /storage/volumes/{volume.uuid}/top-metrics/users`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[Resource]`

    Retrieves a list of users with the most I/O activity.

    ### Learn more

    - `DOC /storage/volumes/{volume.uuid}/top-metrics/users`

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class TopMetricsUserSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the TopMetricsUser object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `iops: TopMetricsSvmUserIops GET POST PATCH`

    The iops field of the top_metrics_user.

  `svm: Svm GET`

    The svm field of the top_metrics_user.

  `throughput: TopMetricsSvmUserThroughput GET POST PATCH`

    The throughput field of the top_metrics_user.

  `user_id: str GET`

    User ID of the user.

    Example: S-1-5-21-256008430-3394229847-3930036330-1001

  `user_name: str GET`

    Name of the user.

    Example: James

  `volume: Volume GET`

    The volume field of the top_metrics_user.